@@ -9,7 +9,6 @@ import unittest
 import re
 from Bio import SeqIO
 unittest.TestLoader.sortTestMethodsUsing = None
-from json import JSONDecodeError
 
 import protpy as protpy
 
@@ -59,6 +58,8 @@ class ProtPyAutocorrelationTests(unittest.TestCase):
             self.assertIsInstance(moreaubroto_seq1, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moreaubroto_seq1.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moreaubroto_seq1.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moreaubroto_seq1.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
             #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
@@ -66,16 +67,14 @@ class ProtPyAutocorrelationTests(unittest.TestCase):
                 self.assertTrue(bool(re.match(r"MoreauBrotoAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))     
 #2.)
-        moreaubroto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in moreaubroto_lag:
             moreaubroto_seq2 = protpy.moreaubroto_autocorrelation(self.protein_seq2, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(moreaubroto_seq2, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moreaubroto_seq2.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moreaubroto_seq2.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moreaubroto_seq2.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
             #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
@@ -83,16 +82,14 @@ class ProtPyAutocorrelationTests(unittest.TestCase):
                 self.assertTrue(bool(re.match(r"MoreauBrotoAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))
 #3.)
-        moreaubroto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in moreaubroto_lag:
             moreaubroto_seq3 = protpy.moreaubroto_autocorrelation(self.protein_seq3, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(moreaubroto_seq3, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moreaubroto_seq3.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moreaubroto_seq3.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moreaubroto_seq3.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
             #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
@@ -100,16 +97,14 @@ class ProtPyAutocorrelationTests(unittest.TestCase):
                 self.assertTrue(bool(re.match(r"MoreauBrotoAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))
 #4.)
-        moreaubroto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in moreaubroto_lag:
             moreaubroto_seq4 = protpy.moreaubroto_autocorrelation(self.protein_seq4, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(moreaubroto_seq4, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moreaubroto_seq4.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moreaubroto_seq4.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moreaubroto_seq4.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
             #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
@@ -143,59 +138,55 @@ class ProtPyAutocorrelationTests(unittest.TestCase):
             self.assertIsInstance(moran_auto_seq1, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moran_auto_seq1.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moran_auto_seq1.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moran_auto_seq1.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of MoranAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(moran_auto_seq1.columns):
                 self.assertTrue(bool(re.match(r"MoranAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))
 #2.)
-        moran_auto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in moran_auto_lag:
             moran_auto_seq2 = protpy.moran_autocorrelation(self.protein_seq2, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(moran_auto_seq2, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moran_auto_seq2.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moran_auto_seq2.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moran_auto_seq2.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of MoranAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(moran_auto_seq2.columns):
                 self.assertTrue(bool(re.match(r"MoranAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))
 #3.)
-        moran_auto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in moran_auto_lag:
             moran_auto_seq3 = protpy.moran_autocorrelation(self.protein_seq3, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(moran_auto_seq3, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moran_auto_seq3.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moran_auto_seq3.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moran_auto_seq3.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of MoranAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(moran_auto_seq3.columns):
                 self.assertTrue(bool(re.match(r"MoranAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}".format(col))
 #4.)
-        moran_auto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in moran_auto_lag:
             moran_auto_seq4 = protpy.moran_autocorrelation(self.protein_seq4, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(moran_auto_seq4, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(moran_auto_seq4.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(moran_auto_seq4.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(moran_auto_seq4.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of MoranAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(moran_auto_seq4.columns):
                 self.assertTrue(bool(re.match(r"MoranAuto_[A-Z0-9]{10}_[0-9]", col)), 
@@ -226,59 +217,55 @@ class ProtPyAutocorrelationTests(unittest.TestCase):
             self.assertIsInstance(geary_auto_seq1, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(geary_auto_seq1.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(geary_auto_seq1.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(geary_auto_seq1.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of GearyAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(geary_auto_seq1.columns):
                 self.assertTrue(bool(re.match(r"GearyAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))
 #2.)
-        geary_auto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in geary_auto_lag:
             geary_auto_seq2 = protpy.geary_autocorrelation(self.protein_seq2, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(geary_auto_seq2, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(geary_auto_seq2.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(geary_auto_seq2.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(geary_auto_seq2.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of GearyAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(geary_auto_seq2.columns):
                 self.assertTrue(bool(re.match(r"GearyAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}.".format(col))
 #3.)
-        geary_auto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in geary_auto_lag:
             geary_auto_seq3 = protpy.geary_autocorrelation(self.protein_seq3, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(geary_auto_seq3, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(geary_auto_seq3.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(geary_auto_seq3.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(geary_auto_seq3.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of GearyAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(geary_auto_seq3.columns):
                 self.assertTrue(bool(re.match(r"GearyAuto_[A-Z0-9]{10}_[0-9]", col)), 
                     "Column name doesn't match expected regex pattern: {}".format(col))
 #4.)
-        geary_auto_lag = list(range(5, 35, 5))
-        properties = ["CIDH920105", "BHAR880101", "CHAM820101", "CHAM820102", 
-            "CHOC760101", "BIGC670101", "CHAM810101", "DAYM780201"]
-
         for lag in geary_auto_lag:
             geary_auto_seq4 = protpy.geary_autocorrelation(self.protein_seq4, lag=lag, 
                 properties=properties, normalize=True)
             self.assertIsInstance(geary_auto_seq4, pd.DataFrame, 'Descriptor not of type DataFrame.')
             self.assertEqual(geary_auto_seq4.shape, (1, lag*len(properties)), 'Descriptor not of correct shape.') 
             self.assertTrue(geary_auto_seq4.any().isnull().sum()==0, 'Descriptor should not contain any null values.')        
+            self.assertTrue(all(col == np.float64 for col in list(geary_auto_seq4.dtypes)), 
+                "Descriptor values not of correct datatype.")
 
-            #check all columns follow pattern of MoreauBrotoAuto_X_Y where x is the asscession number of
+            #check all columns follow pattern of GearyAuto_X_Y where x is the asscession number of
             #   the AAindex record and y is the count of the descriptor
             for col in list(geary_auto_seq4.columns):
                 self.assertTrue(bool(re.match(r"GearyAuto_[A-Z0-9]{10}_[0-9]", col)), 
