@@ -2,14 +2,10 @@
 #################            protPy Module Tests          #################
 ###########################################################################
 
-import pandas as pd
-import numpy as np
 import os
 import unittest
-import re
 from Bio import SeqIO
 unittest.TestLoader.sortTestMethodsUsing = None
-from json import JSONDecodeError
 
 import protpy as protpy
 
@@ -45,7 +41,7 @@ class ProtPyTests(unittest.TestCase):
 
     def test_protpy_metadata(self):
         """ Testing correct protpy version and metadata. """
-        self.assertEqual(protpy.__version__, "0.0.4", 
+        self.assertEqual(protpy.__version__, "1.0.1", 
             "protpy version is not correct, got: {}".format(protpy.__version__))
         self.assertEqual(protpy.__name__, "protpy", 
             "protpy software name is not correct, got: {}".format(protpy.__name__))
